@@ -29,7 +29,7 @@ class Command:
         files = []
         glob_list = map(lambda x: os.path.abspath(x), GLOB_PATTERN)
         for pattern in glob_list:
-            files.extend(glob.glob(pattern))
+            files.extend(glob.glob(pattern, recursive=True))
 
         if template_names:
             filenames = list(map(lambda x: os.path.abspath(x), template_names))
@@ -55,7 +55,6 @@ class Command:
 
         logging.info(f'[{self.config.env}] Connecting to {self.config.store}')
         logging.info(f'[{self.config.env}] Uploading {template_count} files to theme id {self.config.theme_id}')
-
         for template_name in progress_bar(
                 template_names, prefix=f'[{self.config.env}] Progress:', suffix='Complete', length=50):
             relative_pathfile = get_template_name(template_name)
